/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'use strict';
var assert = require('assert');
var vscode_1 = require('vscode');
var utils_1 = require('./utils');
suite("editor tests", function () {
    teardown(utils_1.cleanUp);
    test('make edit', function () {
        return utils_1.createRandomFile().then(function (file) {
            return vscode_1.workspace.openTextDocument(file).then(function (doc) {
                return vscode_1.window.showTextDocument(doc).then(function (editor) {
                    return editor.edit(function (builder) {
                        builder.insert(new vscode_1.Position(0, 0), 'Hello World');
                    }).then(function (applied) {
                        assert.ok(applied);
                        assert.equal(doc.getText(), 'Hello World');
                        assert.ok(doc.isDirty);
                        return doc.save().then(function (saved) {
                            assert.ok(saved);
                            assert.ok(!doc.isDirty);
                            return utils_1.deleteFile(file);
                        });
                    });
                });
            });
        });
    });
});
//# sourceMappingURL=editor.test.js.map