/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'use strict';
var assert = require('assert');
var vscode = require('vscode');
var fs = require('fs');
var os = require('os');
var path_1 = require('path');
function rndName() {
    return Math.random().toString(36).replace(/[^a-z]+/g, '').substr(0, 10);
}
function createRandomFile(contents) {
    if (contents === void 0) { contents = ''; }
    return new Promise(function (resolve, reject) {
        var tmpFile = path_1.join(os.tmpdir(), rndName());
        fs.writeFile(tmpFile, contents, function (error) {
            if (error) {
                return reject(error);
            }
            resolve(vscode.Uri.file(tmpFile));
        });
    });
}
exports.createRandomFile = createRandomFile;
function pathEquals(path1, path2) {
    if (process.platform !== 'linux') {
        path1 = path1.toLowerCase();
        path2 = path2.toLowerCase();
    }
    return path1 === path2;
}
exports.pathEquals = pathEquals;
function deleteFile(file) {
    return new Promise(function (resolve, reject) {
        fs.unlink(file.fsPath, function (err) {
            if (err) {
                reject(err);
            }
            else {
                resolve(true);
            }
        });
    });
}
exports.deleteFile = deleteFile;
function cleanUp() {
    return new Promise(function (c, e) {
        if (vscode.window.visibleTextEditors.length === 0) {
            return c();
        }
        // TODO: the visibleTextEditors variable doesn't seem to be
        // up to date after a onDidChangeActiveTextEditor event, not
        // even using a setTimeout 0... so we MUST poll :(
        var interval = setInterval(function () {
            if (vscode.window.visibleTextEditors.length > 0) {
                return;
            }
            clearInterval(interval);
            c();
        }, 10);
        vscode.commands.executeCommand('workbench.action.closeAllEditors')
            .then(function () { return vscode.commands.executeCommand('workbench.files.action.closeAllFiles'); })
            .then(null, function (err) {
            clearInterval(interval);
            e(err);
        });
    }).then(function () {
        assert.equal(vscode.window.visibleTextEditors.length, 0);
        assert(!vscode.window.activeTextEditor);
        // TODO: we can't yet make this assertion because when
        // the phost creates a document and makes no changes to it,
        // the main side doesn't know about it and the phost side
        // assumes it exists. Calling closeAllFiles will not
        // remove it from textDocuments array. :(
        // assert.equal(vscode.workspace.textDocuments.length, 0);
    });
}
exports.cleanUp = cleanUp;
//# sourceMappingURL=utils.js.map